@@ -85,10 +85,10 @@ public:
 
     Vlr() = default;
     Vlr(const std::string& userId, uint16_t recordId, const std::string& description) :
-        userId(userId), recordId(recordId), description(description)
+        userId(userId), recordId(recordId), description(description), writeAsEVLR(false)
     {}
     Vlr(const std::string& userId, uint16_t recordId) :
-        userId(userId), recordId(recordId)
+        userId(userId), recordId(recordId), writeAsEVLR(false)
     {}
     virtual ~Vlr() = default;
 
@@ -111,6 +111,9 @@ public:
     std::string description;
     std::vector<char> dataVec;
     std::string metadataId;
+
+    // User specified we want to write this at the back of the file
+    bool writeAsEVLR = false;
 };
 
 inline bool operator==(const Vlr& v1, const Vlr& v2)
@@ -127,11 +130,11 @@ struct Evlr : public Vlr
     Evlr(const std::string& userId, uint16_t recordId,
             const std::string& description, const std::vector<char>& data) :
         Vlr(userId, recordId, description)
-    { dataVec = data; }
+    { dataVec = data; writeAsEVLR = false;}
     Evlr(const std::string& userId, uint16_t recordId,
             const std::string& description, std::vector<char>&& data) :
         Vlr(userId, recordId, description)
-    { dataVec = data; }
+    { dataVec = data; writeAsEVLR = false;}
 
     virtual void fillHeader(const char *buf) override;
     virtual std::vector<char> headerData() const override;
